3D Plotting
===========

All of these plots require the usage of S2PLOT and its Python bindings.  Note,
also, that these require interaction with the user and do not support
disconnected use.  Furthermore, typically after a plot has been created the UI
remains onscreen for the remainder of the Python session.

.. currentmodule:: yt.raven

.. autoclass:: yt.raven.VolumeRendering
   :members:
   :inherited-members:

.. autoclass:: yt.raven.VolumeRenderingDataCube
   :members:
   :inherited-members:

.. autoclass:: yt.raven.VolumeRendering3DProfile
   :members:
   :inherited-members:

.. autoclass:: yt.raven.HaloMassesPositionPlot
   :members:
   :inherited-members:
